/*
 * @Author: your name
 * @Date: 2021-07-12 10:10:05
 * @LastEditTime: 2022-08-03 11:16:07
 * @LastEditors: pangkangrong-123 973534209@qq.com
 * @Description: In User Settings Edit
 * @FilePath: \fe-component-lib\src\common\js\xMixin.js
 */
import golbalConfig from "./config";
import { hasAuth } from "./directives";
import {
  filterStr
  // checkPhone
  // , comdify, delcommafy
} from "./defaultFunction.js";
export default function() {
  return {
    model: {
      prop: "propData",
      event: "input"
    },
    props: {
      config: {
        type: Object,
        default: () => {
          return {};
        },
        require: true
      },
      propData: {
        default: undefined
      },
      handleData: {
        default: undefined
      },
      scopeData: {
        default: undefined
      }
    },
    data() {
      return {
        formData: this.propData,
        golbalConfig: golbalConfig.get(),
        // 保存全局 $loading
        fullLoading: null
      };
    },
    methods: {
      //判断返回值
      computedReturn(fn = null, data = null) {
        if (fn != null) {
          if (typeof fn === "function") {
            return fn(data);
          }
        }
        return fn;
      },
      //组件 label 解析
      computedConfigLabel(label, config) {
        if (typeof label == "string") {
          return label;
        } else if (typeof label == "function") {
          return label(config);
        }
      },
      // 提示确认确认框
      /**
       *
       * @param {*} tips 提示文字
       * @param {*} confirmFn 确定执行方法
       * @param {*} catchFn  取消执行方法
       */
      confirm(tips, confirmFn, catchFn, type = "warning") {
        this.$confirm(`${tips}, 是否继续?`, "提示", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: type
        })
          .then(() => {
            if (confirmFn) {
              confirmFn();
            }
          })
          .catch(() => {
            if (catchFn) {
              catchFn();
            }
            // this.$message({
            //   type: "info",
            //   message: "已取消删除"
            // });
          });
      },
      /**
       *
       * @param {*} obj.loadingText  文字
       * @param {*} obj.spinner   icon
       * @param {*} obj.target  loading的主体 默认 body  self.$refs.myTables.$el
       */
      loading(obj = {}) {
        var self = this;
        // loadingText = "加载中...",
        // spinner = "el-icon-loading",
        // target = document.body
        this.fullLoading = this.$loading({
          lock: self.computeBoolen(obj.lock, true),
          text: obj.loadingText || "加载中...",
          spinner: obj.spinner || "el-icon-loading",
          target: obj.target || document.body,
          background: obj.background || null
        });
      },
      // 关闭加载中样式
      /**
       *
       * @param {*} loading  传入需要关闭的loading主体
       */
      loadingClose(loading = this.fullLoading) {
        loading.close();
      },
      /**
       * 计算出布尔值，并且可以配置默认值
       */
      /**
       *
       * @param {*} value  boolean/function
       * @param {*} defaultValue 自定义默认值
       * @returns    默认false;
       */
      computeBoolen(value, defaultValue, obj = null) {
        if (this.isBoolen(value)) return value;
        if (this.isEmpty(value)) {
          if (defaultValue) {
            return defaultValue;
          } else {
            return false;
          }
        }
        if (this.isFunction(value)) {
          // console.log(8888888888888);
          if (obj) {
            return value(obj);
          } else {
            return value(this.propData, this.handleData, this.scopeData);
          }
        }
        return true;
      },
      /**
       *判断为空 null undefined
       * @param {*} value
       * @returns
       */
      isEmpty(value) {
        if (
          value === "null" ||
          value == null ||
          value === "undefined" ||
          value === undefined ||
          value === ""
        ) {
          return true;
        } else {
          return false;
        }
      },
      /**
       * 判断是否是 boolean
       */
      isBoolen(value) {
        return typeof value === "boolean";
      },
      /**
       * 判断是否是Function
       * @param {*} value
       */
      isFunction(value) {
        return typeof value === "function";
      },
      /**
       * 判断是否是 对象
       */
      isObject(value) {
        return typeof value === "object";
      },
      // 默认事件
      /**
       *
       * @param {*} fun  配置的事件方法
       * @param  {...any} data 系统默认的参数
       * @returns
       */
      computeFunction(fun, ...data) {
        if (fun) {
          if (typeof fun === "string") {
            //方法名配置字符串时，触发回调函数
            // console.log("...data", ...data);
            this.$emit("watchCallBackFunItem", {
              name: fun,
              defaultCallBackData: [...data]
            });
          } else if (typeof fun === "function") {
            // 配置成方法时 直接触发 handleData  为组件props 的handleData
            this.$nextTick(() => {
              fun(...data, this.handleData, this.scopeData);
            });
          } else {
            return false;
          }
        } else {
          return false;
        }
      },
      /**
       * 只能输入正负数字和小数点
       */
      NumberCheck(val) {
        const t = val.charAt(0);
        // 转化为数字形式--包含小数，负数
        // 先把非数字的都替换掉，除了数字和.
        val = val.replace(/[^\d.]/g, "");
        // 必须保证第一个为数字而不是.
        val = val.replace(/^\./g, "");
        // 保证只有出现一个.而没有多个.
        val = val.replace(/\.{2,}/g, ".");
        // 保证.只出现一次，而不能出现两次以上
        val = val
          .replace(".", "$#$")
          .replace(/\./g, "")
          .replace("$#$", ".");
        // 如果第一位是负号，则允许添加
        if (t === "-") {
          val = "-" + val;
        }
        return val;
      },

      //默认输入框input 事件 动态过滤特殊字符 校验手机或者邮箱 金额或者数字
      /**
       *
       * @param {*} e 默认事件值
       * @param {*} valueType 配置的valueType值
       * @param {*} fn 配置的input事件
       * @returns
       */
      defaultInput(e, valueType, fn, config) {
        if (this.formData) {
          let newFormData = filterStr(this.formData, true);
          //输入框内容是
          if (["money", "number"].includes(valueType)) {
            // 过滤特殊字符的同时限制只能输入数字
            this.formData = this.NumberCheck(this.formData);
            // if (["money"].includes(valueType)) {
            const { toFixedNum, positiveNumber } = config; // 存在配置自定义保留小数的位数
            if (typeof positiveNumber === "boolean" && positiveNumber) {
              //正数
              if (
                this.formData != null &&
                String(this.formData).indexOf("-") != -1
              ) {
                this.formData = this.formData.replace("-", "");
              }
            }
            if (toFixedNum != undefined || toFixedNum != null) {
              if (
                this.formData != null &&
                String(this.formData).indexOf(".") != -1
              ) {
                let pointNum = String(this.formData).split("."); //小数的位数
                if (toFixedNum == 0) {
                  // 只能输入正正数
                  this.formData = `${pointNum[0]}${pointNum[1].substring()}`;
                } else if (pointNum[1].length > toFixedNum) {
                  this.formData = `${pointNum[0]}.${pointNum[1].substring(
                    0,
                    toFixedNum
                  )}`;
                  // console.log("typeof:", typeof this.formData);
                }
              }
            }
            // }

            // this.formData = this.formData.replace(/[^\d.-]/g, '');
            // if (this.formData !== newFormData) {
            //   console.log("this.formData", this.formData);
            // console.log(
            //   "newFormData",
            //   this.clearNoNum({ value: this.formData })
            // );
            //   this.formData = filterStr(this.formData, true);
            // }

            if (fn) {
              //有input事件就执行回调
              // this.$nextTick(() => {
              // 添加 nextTick修复数据延迟不同步问题
              this.computeFunction(fn, this.formData);
              // });
              return;
            }
          } else if (valueType == "phone") {
            // 校验电话号码 暂时预留
            // console.log("checkPhone", checkPhone(this.formData));
          } else if (valueType == "email") {
            // 校验邮箱 暂时预留
          } else {
            // 过滤特殊字符
            if (this.formData !== newFormData) {
              this.formData = filterStr(this.formData);
            }
          }
        }
        if (fn) {
          // this.$nextTick(() => {
          // 添加 nextTick修复数据延迟不同步问题
          this.computeFunction(fn, e);
          // });
        }
      }
    },
    watch: {
      formData: {
        handler(val) {
          // console.log("更新22", val);
          // val = filterStr(val);
          //注意： 异步 导致input的input方法修改数据没有显示
          this.$emit("input", val);
          this.$emit("change", val);
        },
        deep: true
      },
      propData: {
        handler(val) {
          // val = filterStr(val);
          // console.log("propData", val);
          this.formData = val;
          // this.$emit("input", val);
        },
        deep: true
      }
    },
    directives: {
      hasAuth: hasAuth()
    }
  };
}
